@@ -1,4 +1,6 @@
 package App::SmokeBox::Mini;
+$App::SmokeBox::Mini::VERSION = '0.66';
+#ABSTRACT: the guts of the minismokebox command
 
 use strict;
 use warnings;
@@ -22,13 +24,9 @@ use POE::Component::SmokeBox::Dists;
 use POE::Component::SmokeBox::Recent;
 use App::SmokeBox::PerlVersion;
 
-use vars qw($VERSION);
-
 use constant CPANURL => 'ftp://cpan.cpantesters.org/CPAN/';
 
-$VERSION = '0.64';
-
-$ENV{PERL5_MINISMOKEBOX} = $VERSION;
+$ENV{PERL5_MINISMOKEBOX} = $App::SmokeBox::Mini::VERSION;
 
 sub _smokebox_dir {
   return $ENV{PERL5_SMOKEBOX_DIR}
@@ -96,7 +94,7 @@ sub _get_jobs_from_file {
 }
 
 sub _display_version {
-  print "minismokebox version ", $VERSION,
+  print "minismokebox version ", $App::SmokeBox::Mini::VERSION,
     ", powered by POE::Component::SmokeBox ", POE::Component::SmokeBox->VERSION, "\n\n";
   print <<EOF;
 Copyright (C) 2011 Chris 'BinGOs' Williams
@@ -418,12 +416,21 @@ sub _smoke {
 }
 
 'smoke it!';
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 App::SmokeBox::Mini - the guts of the minismokebox command
 
+=head1 VERSION
+
+version 0.66
+
 =head1 SYNOPSIS
 
   #!/usr/bin/perl
@@ -439,12 +446,13 @@ This method is called by L<minismokebox> to do all the work.
 
 =head1 AUTHOR
 
-Chris C<BinGOs> Williams <chris@bingosnet.co.uk>
+Chris Williams <chris@bingosnet.co.uk>
 
-=head1 LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright E<copy> Chris Williams
+This software is copyright (c) 2017 by Chris Williams.
 
-This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
