@@ -1,18 +1,26 @@
 package App::SmokeBox::Mini::Plugin;
+$App::SmokeBox::Mini::Plugin::VERSION = '0.66';
+#ABSTRACT: minismokebox plugins
 
 use strict;
 use warnings;
 
-our $VERSION = '0.64';
-
 qq[Smokin' plugins];
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 App::SmokeBox::Mini::Plugin - minismokebox plugins
 
+=head1 VERSION
+
+version 0.66
+
 =head1 DESCRIPTION
 
 This document describes the App::SmokeBox::Mini::Plugin system for
@@ -81,7 +89,6 @@ Each result is a hashref:
   'excess_kill', only present if the job was killed due to excessive runtime;
   'term_kill', only present if the job was killed due to a poco shutdown event;
 
-
 =item C<sbox_stop>
 
 Sent when the smokebox is terminating. Your plugin session should terminate after receiving this
@@ -100,14 +107,13 @@ event. The following data will be passed:
 
 =head1 AUTHOR
 
-Chris C<BinGOs> Williams <chris@bingosnet.co.uk>
+Chris Williams <chris@bingosnet.co.uk>
 
-=head1 LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright E<copy> Chris Williams
+This software is copyright (c) 2017 by Chris Williams.
 
-This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
-
-=head1 SEE ALSO
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
